@@ -22,8 +22,8 @@ sub parse {
 	
 	# here we want to expand some generic params
 	my $expand = {
-		root => $core->root->path,
-		id   => $core->id,
+		root   => $core->root->path,
+		id     => $core->id,
 		distro => $core->distro,
 	};
 	
@@ -40,6 +40,18 @@ sub parse {
 	return $data;
 }
 
+sub string_from_template {
+	
+	my $template  = shift;
+	my $expansion = shift;
+	
+	foreach (keys %$expansion) {
+		$template =~ s/\{\$$_\}/$expansion->{$_}/sg;
+	}
+	
+	return $template;
+}
+
 sub patch ($$) {
 	my $struct    = shift;
 	my $patch     = shift;
